@@ -115,7 +115,6 @@ def test_floats_5():
     # c414-flt-wrap-000 with text ... more or less
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body { width: 100px; font: 60px weasyprint; }
         p { float: left; height: 100px }
         img { width: 60px; vertical-align: top }
@@ -308,9 +307,6 @@ def test_floats_page_breaks_3():
 def test_preferred_widths_1():
     def get_float_width(body_width):
         page, = render_pages('''
-          <style>
-            @font-face { src: url(weasyprint.otf); font-family: weasyprint }
-          </style>
           <body style="width: %spx; font-family: weasyprint">
           <p style="white-space: pre-line; float: left">
             Lorem ipsum dolor sit amet,
@@ -361,7 +357,6 @@ def test_preferred_widths_3():
 def test_preferred_widths_4():
     page, = render_pages(
         '<style>'
-        '  @font-face { src: url(weasyprint.otf); font-family: weasyprint }'
         '  p { font: 20px weasyprint }'
         '</style>'
         '<p style="float: left">XX<br>XX<br>X</p>')
@@ -376,7 +371,6 @@ def test_preferred_widths_5():
     # The space is the start of the line is collapsed.
     page, = render_pages(
         '<style>'
-        '  @font-face { src: url(weasyprint.otf); font-family: weasyprint }'
         '  p { font: 20px weasyprint }'
         '</style>'
         '<p style="float: left">XX<br> XX<br>X</p>')
@@ -390,7 +384,6 @@ def test_preferred_widths_5():
 def test_float_in_inline_1():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body {
           font-family: weasyprint;
           font-size: 20px;
@@ -435,7 +428,6 @@ def test_float_in_inline_1():
 def test_float_in_inline_2():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         @page {
           size: 10em;
         }
@@ -471,7 +463,6 @@ def test_float_in_inline_2():
 def test_float_in_inline_3():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         @page {
           size: 10em;
         }
@@ -506,7 +497,6 @@ def test_float_in_inline_3():
 def test_float_in_inline_4():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         @page {
           size: 10em;
         }
@@ -543,7 +533,6 @@ def test_float_in_inline_4():
 def test_float_next_line():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body {
           font-family: weasyprint;
           font-size: 20px;
@@ -576,7 +565,6 @@ def test_float_next_line():
 def test_float_text_indent_1():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body {
           font-family: weasyprint;
           font-size: 20px;
@@ -611,7 +599,6 @@ def test_float_text_indent_1():
 def test_float_text_indent_2():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body {
           font-family: weasyprint;
           font-size: 20px;
@@ -653,7 +640,6 @@ def test_float_text_indent_2():
 def test_float_text_indent_3():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body {
           font-family: weasyprint;
           font-size: 20px;
@@ -700,7 +686,6 @@ def test_float_text_indent_3():
 def test_float_previous_break():
     page1, page2 = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         @page {
           size: 13px;
         }
@@ -747,7 +732,6 @@ def test_float_previous_break():
 def test_float_fail():
     page, = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         body {
           font-family: weasyprint;
           font-size: 20px;
@@ -774,7 +758,6 @@ def test_float_fail():
 def test_float_table_aborted_row():
     page1, page2 = render_pages('''
       <style>
-        @font-face {src: url(weasyprint.otf); font-family: weasyprint}
         @page {size: 10px 7px}
         body {font-family: weasyprint; font-size: 2px; line-height: 1}
         div {float: right; orphans: 1}
@@ -815,3 +798,11 @@ def test_float_table_aborted_row():
     assert textbox.text == 'f'
     textbox, = line2.children
     assert textbox.text == 'g'
+
+
+def test_formatting_context_avoid_rtl():
+    render_pages('''
+      <div style="direction: rtl">
+        <div style="overflow: hidden"></div>
+      </div>
+    ''')
