@@ -877,7 +877,7 @@ def test_page_names_10():
     page1, page2 = pages
 
     assert (page1.width, page1.height) == (100, 100)
-    html, runing = page1.children
+    html, running = page1.children
     body, = html.children
     fixed, section, = body.children
     h1, pagebreak = section.children
@@ -891,6 +891,152 @@ def test_page_names_10():
     assert article.element_tag == 'article'
 
 
+@assert_no_logs
+def test_page_groups():
+    pages = render_pages('''
+      <style>
+        @page { size: 200px 200px }
+        @page small { size: 100px 100px }
+        @page :nth(1 of small) { size: 50px 50px }
+        section { page: small }
+        div, div section { break-after: page }
+      </style>
+      <div></div>
+      <article></article>
+      <section>
+        <div></div>
+        <div></div>
+      </section>
+      <section>
+      </section>
+      <div></div>
+      <div></div>
+      <section>
+        <div></div>
+      </section>
+      <div>
+        <section></section>
+        <section></section>
+      </div>
+    ''')
+    page1, page2, page3, page4, page5, page6, page7, page8, page9 = pages
+
+    assert (page1.width, page1.height) == (200, 200)
+    div, = page1.children[0].children[0].children
+    assert div.element_tag == 'div'
+
+    assert (page2.width, page2.height) == (200, 200)
+    article, = page2.children[0].children[0].children
+    assert article.element_tag == 'article'
+
+    assert (page3.width, page3.height) == (50, 50)
+    section, = page3.children[0].children[0].children
+    assert section.element_tag == 'section'
+    div, = section.children
+    assert div.element_tag == 'div'
+
+    assert (page4.width, page4.height) == (100, 100)
+    section, = page4.children[0].children[0].children
+    assert section.element_tag == 'section'
+    div, = section.children
+    assert div.element_tag == 'div'
+
+    assert (page5.width, page5.height) == (50, 50)
+    section, div = page5.children[0].children[0].children
+    assert section.element_tag == 'section'
+    assert div.element_tag == 'div'
+
+    assert (page6.width, page6.height) == (200, 200)
+    div, = page6.children[0].children[0].children
+    assert div.element_tag == 'div'
+
+    assert (page7.width, page7.height) == (50, 50)
+    section, = page7.children[0].children[0].children
+    assert section.element_tag == 'section'
+    div, = section.children
+    assert div.element_tag == 'div'
+
+    assert (page8.width, page8.height) == (50, 50)
+    div, = page8.children[0].children[0].children
+    assert div.element_tag == 'div'
+    section, = div.children
+    assert section.element_tag == 'section'
+
+    assert (page9.width, page9.height) == (50, 50)
+    div, = page9.children[0].children[0].children
+    assert div.element_tag == 'div'
+    section, = div.children
+    assert section.element_tag == 'section'
+
+
+@assert_no_logs
+def test_page_groups_blank_inside():
+    # Regression test for #1076.
+    pages = render_pages('''
+      <style>
+        @page { size: 100px }
+        @page div { size: 50px }
+        div { page: div }
+        p { break-before: right }
+      </style>
+      <div>
+        <p>1</p>
+        <p>2</p>
+      </div>
+    ''')
+    assert len(pages) == 3
+    for page in pages:
+        assert (page.width, page.height) == (50, 50)
+
+
+@assert_no_logs
+def test_page_groups_blank_outside():
+    pages = render_pages('''
+      <style>
+        @page { size: 100px }
+        @page p { size: 50px }
+        p { page: p; break-before: right }
+      </style>
+      <div>
+        <p>1</p>
+        <p>2</p>
+      </div>
+    ''')
+    page1, page2, page3 = pages
+    for page in (page1, page3):
+        assert (page.width, page.height) == (50, 50)
+    assert (page2.width, page2.height) == (100, 100)
+
+
+@assert_no_logs
+def test_page_groups_first_nth():
+    # Regression test for #2429.
+    pages = render_pages('''
+      <style>
+        @page { size: 100px }
+        @page div { size: 50px }
+        @page :nth(2n+1 of div) { size: 30px }
+        div { page: div; break-before: right }
+        p { break-before: page }
+      </style>
+      <div>
+        <p>1</p>
+        <p>2</p>
+        <p>3</p>
+      </div>
+      <div>
+        <p>4</p>
+        <p>5</p>
+      </div>
+    ''')
+    page1, page2, page3, page4, page5, page6 = pages
+    for page in (page1, page3, page5):
+        assert (page.width, page.height) == (30, 30)
+    for page in (page2, page6):
+        assert (page.width, page.height) == (50, 50)
+    assert (page4.width, page4.height) == (100, 100)
+
+
 @assert_no_logs
 @pytest.mark.parametrize('style, line_counts', (
     ('orphans: 2; widows: 2', [4, 3]),
@@ -926,7 +1072,6 @@ def test_page_and_linebox_breaking():
     # Empty <span/> tests a corner case in skip_first_whitespace()
     pages = render_pages('''
       <style>
-        @font-face { src: url(weasyprint.otf); font-family: weasyprint }
         @page { size: 100px; margin: 2px; border: 1px solid }
         body { margin: 0 }
         div { font-family: weasyprint; font-size: 20px }
