@@ -4,6 +4,7 @@ import contextlib
 import gzip
 import io
 import os
+import re
 import sys
 import threading
 import unicodedata
@@ -18,6 +19,7 @@ from PIL import Image
 
 from weasyprint import CSS, HTML, __main__, default_url_fetcher
 from weasyprint.pdf.anchors import resolve_links
+from weasyprint.pdf.metadata import generate_rdf_metadata
 from weasyprint.urls import path2url
 
 from .draw import parse_pixels
@@ -127,8 +129,10 @@ def _round_meta(pages):
     """Eliminate errors of floating point arithmetic for metadata."""
     for page in pages:
         anchors = page.anchors
-        for anchor_name, (pos_x, pos_y) in anchors.items():
-            anchors[anchor_name] = round(pos_x, 6), round(pos_y, 6)
+        for anchor_name, (x1, y1, x2, y2) in anchors.items():
+            anchors[anchor_name] = (
+                round(x1, 6), round(y1, 6),
+                round(x2, 6), round(y2, 6))
         links = page.links
         for i, link in enumerate(links):
             link_type, target, rectangle, box = link
@@ -305,6 +309,15 @@ def test_python_render(assert_pixels_equal, tmp_path):
     ).write_png() == rotated_png_bytes
 
 
+@assert_no_logs
+def test_unknown_options():
+    with capture_logs() as logs:
+        pdf_bytes = FakeHTML(string='test').write_pdf(zoom=2, unknown=True)
+    assert len(logs) == 1
+    assert 'unknown' in logs[0]
+    assert pdf_bytes
+
+
 @assert_no_logs
 def test_command_line_render(tmp_path):
     css = b'''
@@ -403,14 +416,14 @@ def test_command_line_render(tmp_path):
         os.environ.pop('SOURCE_DATE_EPOCH')
 
         stdout = _run('combined.html --uncompressed-pdf -')
-        assert stdout.count(b'attachment') == 0
+        assert stdout.count(b'Filespec') == 0
         stdout = _run('combined.html --uncompressed-pdf -')
-        assert stdout.count(b'attachment') == 0
+        assert stdout.count(b'Filespec') == 0
         stdout = _run('-a pattern.png --uncompressed-pdf combined.html -')
-        assert stdout.count(b'attachment') == 1
+        assert stdout.count(b'Filespec') == 1
         stdout = _run(
             '-a style.css -a pattern.png --uncompressed-pdf combined.html -')
-        assert stdout.count(b'attachment') == 2
+        assert stdout.count(b'Filespec') == 2
 
         _run('combined.html out23.pdf --timeout 30')
         assert (tmp_path / 'out23.pdf').read_bytes() == pdf_bytes
@@ -512,10 +525,51 @@ def test_partial_pdf_custom_metadata():
     assert b'value' in stdout
 
 
+def test_pdf_srgb():
+    stdout = _run('--srgb --uncompressed-pdf - -', b'test')
+    assert b'sRGB' in stdout
+
+
+def test_pdf_no_srgb():
+    stdout = _run('--uncompressed-pdf - -', b'test')
+    assert b'sRGB' not in stdout
+
+
+def test_pdf_font_name():
+    # Regression test for #2396.
+    stdout = _run('--uncompressed-pdf - -', b'<div style="font-family:weasyprint">test')
+    assert b'+weasyprint/' in stdout
+
+
+def test_cmap():
+    # Regression test for #2388.
+    stdout = _run('--uncompressed-pdf --full-fonts - -', b'test')
+    matches = re.findall(b'(\\d+) beginbfchar', stdout)
+    assert matches
+    for match in matches:
+        assert int(match) <= 100
+
+
+def test_cmap_rtl():
+    # Regression test for #378.
+    stdout = _run(
+        '--uncompressed-pdf -e utf-8 - -',
+        '<div style="font-family: weasyprint">اب'.encode())
+    assert b'<00cf> <0627>' in stdout
+    assert b'<00d0> <0628>' in stdout
+
+
 @pytest.mark.parametrize('html, fields', (
     ('<input>', ['/Tx', '/V ()']),
     ('<input value="">', ['/Tx', '/V ()']),
     ('<input type="checkbox">', ['/Btn']),
+    ('<input type="radio">',
+     ['/Btn', '/V /Off', '/AS /Off', '/Ff 49152']),
+    ('<input checked type="radio" name="foo" value="value">',
+     ['/Btn', '/T (foo)', '/V /0', '/AS /0']),
+    ('<form><input type="radio" name="foo" value="v0"></form>'
+     '<form><input checked type="radio" name="foo" value="v1"></form>',
+     ['/Btn', '/AS /0', '/V /0', '/AS /Off', '/V /Off']),
     ('<textarea></textarea>', ['/Tx', '/V ()']),
     ('<select><option value="a">A</option></select>', ['/Ch', '/Opt']),
     ('<select>'
@@ -531,7 +585,8 @@ def test_partial_pdf_custom_metadata():
 def test_pdf_inputs(html, fields):
     stdout = _run('--pdf-forms --uncompressed-pdf - -', html.encode())
     assert b'AcroForm' in stdout
-    assert all(field.encode() in stdout for field in fields)
+    for field in fields:
+        assert field.encode() in stdout
     stdout = _run('--uncompressed-pdf - -', html.encode())
     assert b'AcroForm' not in stdout
 
@@ -857,8 +912,8 @@ def test_links_1():
         ],
         [('internal', 'hello', (0, 0, 200, 30))],
     ], [
-        {'hello': (0, 200)},
-        {'lipsum': (0, 0)}
+        {'hello': (0, 200, 200, 290)},
+        {'lipsum': (0, 0, 200, 90)}
     ], [
         (
             [
@@ -939,7 +994,7 @@ def test_links_6():
         ''', [[
             ('internal', 'lipsum', (5, 10, 195, 10)),
             ('external', 'https://weasyprint.org/', (0, 10, 200, 10))]],
-        [{'lipsum': (5, 10)}],
+        [{'lipsum': (5, 10, 195, 10)}],
         [([('internal', 'lipsum', (5, 10, 195, 10)),
            ('external', 'https://weasyprint.org/', (0, 10, 200, 10))],
           [('lipsum', 5, 10)])],
@@ -955,7 +1010,7 @@ def test_links_7():
                         margin: 10px 5px" id="lipsum">
         ''',
         [[('internal', 'lipsum', (5, 10, 195, 10))]],
-        [{'lipsum': (5, 10)}],
+        [{'lipsum': (5, 10, 195, 10)}],
         [([('internal', 'lipsum', (5, 10, 195, 10))], [('lipsum', 5, 10)])],
         base_url=None)
 
@@ -971,7 +1026,7 @@ def test_links_8():
         ''',
         [[('internal', 'lipsum', (0, 0, 200, 15)),
           ('internal', 'missing', (0, 15, 200, 30))]],
-        [{'lipsum': (0, 15)}],
+        [{'lipsum': (0, 15, 200, 30)}],
         [([('internal', 'lipsum', (0, 0, 200, 15))], [('lipsum', 0, 15)])],
         base_url=None,
         warnings=[
@@ -987,7 +1042,7 @@ def test_links_9():
                 transform: rotate(90deg) scale(2)">
         ''',
         [[('internal', 'lipsum', (30, 10, 70, 210))]],
-        [{'lipsum': (70, 10)}],
+        [{'lipsum': (70, 10, 30, 210)}],
         [([('internal', 'lipsum', (30, 10, 70, 210))], [('lipsum', 70, 10)])],
         round=True)
 
@@ -1111,6 +1166,7 @@ def assert_meta(html, **meta):
     meta.setdefault('attachments', [])
     meta.setdefault('lang', None)
     meta.setdefault('custom', {})
+    meta.setdefault('generate_rdf_metadata', generate_rdf_metadata)
     assert vars(FakeHTML(string=html).render().metadata) == meta
 
 
