@@ -2,9 +2,9 @@
 
 import pytest
 
-from weasyprint.css import PageType, get_all_computed_styles
+from weasyprint.css import get_all_computed_styles
 from weasyprint.formatting_structure import boxes, build
-from weasyprint.layout.page import set_page_type_computed_styles
+from weasyprint.layout.page import PageType, set_page_type_computed_styles
 
 from .testing_utils import (  # isort:skip
     FakeHTML, assert_no_logs, assert_tree, capture_logs, parse, parse_all,
@@ -248,20 +248,14 @@ def test_whitespace():
 
 @assert_no_logs
 @pytest.mark.parametrize('page_type, top, right, bottom, left', (
-    (PageType(side='left', first=True, index=0, blank=None, name=None),
-     20, 3, 3, 10),
-    (PageType(side='right', first=True, index=0, blank=None, name=None),
-     20, 10, 3, 3),
-    (PageType(side='left', first=None, index=1, blank=None, name=None),
-     10, 3, 3, 10),
-    (PageType(side='right', first=None, index=1, blank=None, name=None),
-     10, 10, 3, 3),
-    (PageType(side='right', first=None, index=1, blank=None, name='name'),
-     5, 10, 3, 15),
-    (PageType(side='right', first=None, index=2, blank=None, name='name'),
-     5, 10, 1, 15),
-    (PageType(side='right', first=None, index=8, blank=None, name='name'),
-     5, 10, 2, 15),
+    (PageType('left', False, '', 0, ()), 20, 3, 3, 10),
+    (PageType('right', False, '', 0, ()), 20, 10, 3, 3),
+    (PageType('left', False, '', 1, ()), 10, 3, 3, 10),
+    (PageType('right', False, '', 1, ()), 10, 10, 3, 3),
+    (PageType('right', False, 'name', 1, (('name', 0),)), 5, 10, 3, 15),
+    (PageType('right', False, 'name', 1, (('name', 1),)), 5, 10, 4, 15),
+    (PageType('right', False, 'name', 2, (('name', 0),)), 5, 10, 1, 15),
+    (PageType('right', False, 'name', 8, (('name', 8),)), 5, 10, 2, 15),
 ))
 def test_page_style(page_type, top, right, bottom, left):
     document = FakeHTML(string='''
@@ -270,6 +264,7 @@ def test_page_style(page_type, top, right, bottom, left):
         @page name { margin-left: 15px; margin-top: 5px }
         @page :nth(3) { margin-bottom: 1px }
         @page :nth(5n+4) { margin-bottom: 2px }
+        @page :nth(2 of name) { margin-bottom: 4px }
         @page :first { margin-top: 20px }
         @page :right { margin-right: 10px; margin-top: 10px }
         @page :left { margin-left: 10px; margin-top: 10px }
@@ -330,6 +325,15 @@ def test_tables_1():
     # Rule 1.3
     # Also table model: https://www.w3.org/TR/CSS21/tables.html#model
     assert_tree(parse_all('''
+      <style>
+        x-table { display: table }
+        x-tr { display: table-row }
+        x-td, x-th { display: table-cell }
+        x-thead { display: table-header-group }
+        x-tfoot { display: table-footer-group }
+        x-col { display: table-column }
+        x-caption { display: table-caption }
+      </style>
       <x-table>
         <x-tr>
           <x-th>foo</x-th>
@@ -420,7 +424,7 @@ def test_tables_3():
 @assert_no_logs
 def test_tables_4():
     # Rules 2.1 then 2.3
-    assert_tree(parse_all('<x-table>foo <div></div></x-table>'), [
+    assert_tree(parse_all('<x-table style="display:table">foo <div></div></x-table>'), [
         ('x-table', 'Block', [
             ('x-table', 'Table', [
                 ('x-table', 'TableRowGroup', [
@@ -435,8 +439,8 @@ def test_tables_4():
 @assert_no_logs
 def test_tables_5():
     # Rule 2.2
-    assert_tree(parse_all('<x-thead style="display: table-header-group">'
-                          '<div></div><x-td></x-td></x-thead>'), [
+    assert_tree(parse_all('<x-thead style="display: table-header-group"><div></div>'
+                          '<x-td style="display: table-cell"></x-td></x-thead>'), [
         ('body', 'Block', [
             ('body', 'Table', [
                 ('x-thead', 'TableRowGroup', [
@@ -449,7 +453,7 @@ def test_tables_5():
 @assert_no_logs
 def test_tables_6():
     # Rule 3.2
-    assert_tree(parse_all('<span><x-tr></x-tr></span>'), [
+    assert_tree(parse_all('<span><x-tr style="display: table-row"></x-tr></span>'), [
         ('body', 'Line', [
             ('span', 'Inline', [
                 ('span', 'InlineBlock', [
@@ -485,7 +489,10 @@ def test_tables_7():
 @assert_no_logs
 def test_tables_8():
     # Rule 3.2
-    assert_tree(parse_all('<x-tr></x-tr>\t<x-tr></x-tr>'), [
+    assert_tree(parse_all(
+        '<x-tr style="display: table-row"></x-tr>\t'
+        '<x-tr style="display: table-row"></x-tr>'
+    ), [
         ('body', 'Block', [
             ('body', 'Table', [
                 ('body', 'TableRowGroup', [
@@ -495,7 +502,10 @@ def test_tables_8():
 
 @assert_no_logs
 def test_tables_9():
-    assert_tree(parse_all('<x-col></x-col>\n<x-colgroup></x-colgroup>'), [
+    assert_tree(parse_all(
+        '<x-col style="display: table-column"></x-col>\n'
+        '<x-colgroup style="display: table-column-group"></x-colgroup>'
+    ), [
         ('body', 'Block', [
             ('body', 'Table', [
                 ('body', 'TableColumnGroup', [
